@@ -27,6 +27,12 @@ def parse_args():
         default=False,
         help="Decide wether domain should be available for all TLDs",
     )
+    generate_parser.add_argument(
+        "--output",
+        type=str,
+        default=None,
+        help="Name of the file were output will be stored",
+    )
 
     args = parser.parse_args()
     if getattr(args, "command", None) is None:
@@ -48,7 +54,9 @@ def main():
             tlds=args.tlds.split(","),
         )
 
-        generator.generate(args.number)
+        generator.generate(
+            args.number, output=open(args.output, "a") if args.output else None
+        )
 
 
 if __name__ == "__main__":
